PowNet Documentation
=====================

|GitHub license|

.. |GitHub license| image:: https://img.shields.io/github/license/Naereen/StrapDown.js.svg
   :target: https://pownet.readthedocs.io/en/latest/pages/license.html

**PowNet: Unit Commitment / Economic Dispatch model in Python**

PowNet is a least-cost optimization model for simulating the Unit Commitment and Economic Dispatch (UC/ED) of large-scale (regional to country) power systems.

Read the PowNet Documentation here: https://pownet.readthedocs.io/en/latest
